@@ -4,9 +4,9 @@ from pysnmp.entity.rfc3413.oneliner import cmdgen
 errorIndication, errorStatus, errorIndex, \
                  varBindTable = cmdgen.CommandGenerator().bulkCmd(
     # SNMP v1
-#    cmdgen.CommunityData('test-agent', 'public', 0),
+#    cmdgen.CommunityData('public', mpModel=0),
     # SNMP v2
-#    cmdgen.CommunityData('test-agent', 'public'),
+#    cmdgen.CommunityData('public'),
     # SNMP v3
     cmdgen.UsmUserData('test-user', 'authkey1', 'privkey1'),
     cmdgen.UdpTransportTarget(('localhost', 161)),
@@ -15,14 +15,15 @@ errorIndication, errorStatus, errorIndex, \
     )
 
 if errorIndication:
-    print errorIndication
+    print(errorIndication)
 else:
     if errorStatus:
-        print '%s at %s\n' % (
+        print('%s at %s' % (
             errorStatus.prettyPrint(),
-            varBindTable[-1][int(errorIndex)-1]
+            errorIndex and varBindTable[-1][int(errorIndex)-1] or '?'
             )
+        )
     else:
         for varBindTableRow in varBindTable:
             for name, val in varBindTableRow:
-                print '%s = %s' % (name.prettyPrint(), val.prettyPrint())
+                print('%s = %s' % (name.prettyPrint(), val.prettyPrint()))
