@@ -4,9 +4,9 @@ from pysnmp.entity.rfc3413.oneliner import cmdgen
 errorIndication, errorStatus, \
                  errorIndex, varBinds = cmdgen.CommandGenerator().getCmd(
     # SNMP v1
-#    cmdgen.CommunityData('test-agent', 'public', 0),
+#    cmdgen.CommunityData('public', mpModel=0),
     # SNMP v2
-    cmdgen.CommunityData('test-agent', 'public'),
+    cmdgen.CommunityData('public'),
     # SNMP v3
 #    cmdgen.UsmUserData('test-user', 'authkey1', 'privkey1'),
     cmdgen.UdpTransportTarget(('localhost', 161)),
@@ -17,12 +17,14 @@ errorIndication, errorStatus, \
     )
 
 if errorIndication:
-    print errorIndication
+    print(errorIndication)
 else:
     if errorStatus:
-        print '%s at %s\n' % (
-            errorStatus.prettyPrint(), varBinds[int(errorIndex)-1]
+        print('%s at %s' % (
+            errorStatus.prettyPrint(),
+            errorIndex and varBinds[int(errorIndex)-1] or '?'
             )
+        )
     else:
         for name, val in varBinds:
-            print '%s = %s' % (name.prettyPrint(), val.prettyPrint())
+            print('%s = %s' % (name.prettyPrint(), val.prettyPrint()))
